import {
    getMainCarrier,
    getSentryCarrier
} from '../carrier.js';
import {
    getStackAsyncContextStrategy
} from './stackStrategy.js';

/**
 * @private Private API with no semver guarantees!
 *
 * Sets the global async context strategy
 */
function setAsyncContextStrategy(strategy) {
    // Get main carrier (global for every environment)
    const registry = getMainCarrier();
    const sentry = getSentryCarrier(registry);
    sentry.acs = strategy;
}

/**
 * Get the current async context strategy.
 * If none has been setup, the default will be used.
 */
function getAsyncContextStrategy(carrier) {
    const sentry = getSentryCarrier(carrier);

    if (sentry.acs) {
        return sentry.acs;
    }

    // Otherwise, use the default one (stack)
    return getStackAsyncContextStrategy();
}

export {
    getAsyncContextStrategy,
    setAsyncContextStrategy
};
//# sourceMappingURL=index.js.map